==> haskell-double-conversion-2.0.2.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-double-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: double-conversion
version: 2.0.2.0
id: double-conversion-2.0.2.0-EPnGpOihhcB3Y8jOBjJCFW
key: double-conversion-2.0.2.0-EPnGpOihhcB3Y8jOBjJCFW
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/double-conversion
synopsis: Fast conversion between double precision floating point and text
description:
    A library that performs fast, accurate conversion between double
    precision floating point and text.
    .
    This library is implemented as bindings to the C++
    @double-conversion@ library written by Florian Loitsch at Google:
    <https://github.com/floitsch/double-conversion>.
    .
    The '\''Text'\'' versions of these functions are about 30 times faster
    than the default '\''show'\'' implementation for the '\''Double'\'' type.
    .
    The '\''ByteString'\'' versions are /slower/ than the '\''Text'\'' versions;
    roughly half the speed.  (This seems to be due to the cost of
    allocating '\''ByteString'\'' values via @malloc@.)
    .
    As a final note, be aware that the @bytestring-show@ package is
    about 50% slower than simply using '\''show'\''.
category: Text
abi: 8cd1a694a6ac7b9bc19f8c6322e65ead
exposed: True
exposed-modules:
    Data.Double.Conversion.ByteString Data.Double.Conversion.Text
hidden-modules: Data.Double.Conversion.FFI
import-dirs: /usr/lib/ghc-8.6.5/site-local/double-conversion-2.0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/double-conversion-2.0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/double-conversion-2.0.2.0
hs-libraries: HSdouble-conversion-2.0.2.0-EPnGpOihhcB3Y8jOBjJCFW
extra-libraries:
    stdc++ double-conversion
depends:
    base-4.12.0.0 bytestring-0.10.8.2 ghc-prim-0.5.3 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-double-conversion/html/double-conversion.haddock
haddock-html: /usr/share/doc/haskell-double-conversion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-double-conversion-2.0.2.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-double-conversion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: double-conversion
version: 2.0.2.0
id: double-conversion-2.0.2.0-1KkJutkoP2qJcsxQMMncw9
key: double-conversion-2.0.2.0-1KkJutkoP2qJcsxQMMncw9
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/double-conversion
synopsis: Fast conversion between double precision floating point and text
description:
    A library that performs fast, accurate conversion between double
    precision floating point and text.
    .
    This library is implemented as bindings to the C++
    @double-conversion@ library written by Florian Loitsch at Google:
    <https://github.com/floitsch/double-conversion>.
    .
    The '\''Text'\'' versions of these functions are about 30 times faster
    than the default '\''show'\'' implementation for the '\''Double'\'' type.
    .
    The '\''ByteString'\'' versions are /slower/ than the '\''Text'\'' versions;
    roughly half the speed.  (This seems to be due to the cost of
    allocating '\''ByteString'\'' values via @malloc@.)
    .
    As a final note, be aware that the @bytestring-show@ package is
    about 50% slower than simply using '\''show'\''.
category: Text
abi: a92dd8e8d8290007e945dca1c7c783ba
exposed: True
exposed-modules:
    Data.Double.Conversion.ByteString Data.Double.Conversion.Text
hidden-modules: Data.Double.Conversion.FFI
import-dirs: /usr/lib/ghc-8.6.5/site-local/double-conversion-2.0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/double-conversion-2.0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/double-conversion-2.0.2.0
hs-libraries: HSdouble-conversion-2.0.2.0-1KkJutkoP2qJcsxQMMncw9
extra-libraries:
    stdc++ double-conversion
depends:
    base-4.12.0.0 bytestring-0.10.8.2 ghc-prim-0.5.3 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-double-conversion/html/double-conversion.haddock
haddock-html: /usr/share/doc/haskell-double-conversion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
